<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Mailing List';
$labels['listcommands_help'] = 'Help';
$labels['listcommands_subscribe'] = 'Subscribe';
$labels['listcommands_unsubscribe'] = 'Unsubscribe';
$labels['listcommands_post'] = 'Post';
$labels['listcommands_admin'] = 'Contact Administrator';
$labels['listcommands_archive'] = 'List Archive';

?>
