<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Email Lijst';
$labels['listcommands_help'] = 'Hulp';
$labels['listcommands_subscribe'] = 'Aanmelden';
$labels['listcommands_unsubscribe'] = 'Afmelden';
$labels['listcommands_post'] = 'Nieuw Bericht';
$labels['listcommands_admin'] = 'Email Beheerder';
$labels['listcommands_archive'] = 'Lijst Archief';

?>
