<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Lista de correo';
$labels['listcommands_help'] = 'Ayuda';
$labels['listcommands_subscribe'] = 'Darse de alta';
$labels['listcommands_unsubscribe'] = 'Darse de baja';
$labels['listcommands_post'] = 'Publicar';
$labels['listcommands_admin'] = 'Contactar con el administrador';
$labels['listcommands_archive'] = 'Archivo de la lista';

?>
