<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Mailing Liste';
$labels['listcommands_help'] = 'Hilfe';
$labels['listcommands_subscribe'] = 'Eintragen';
$labels['listcommands_unsubscribe'] = 'Austragen';
$labels['listcommands_post'] = 'Posten';
$labels['listcommands_admin'] = 'Administrator kontaktieren';
$labels['listcommands_archive'] = 'Archive';

?>
