<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Mailing List';
$labels['listcommands_help'] = 'Aiuto';
$labels['listcommands_subscribe'] = 'Abbona';
$labels['listcommands_unsubscribe'] = 'Disdici';
$labels['listcommands_post'] = 'Scrivi';
$labels['listcommands_admin'] = 'Contatta Amministratore';
$labels['listcommands_archive'] = 'Archivio Lista';
