<?php

$labels = array();

$labels['listcommands_mailinglist'] = 'Mailing List';
$labels['listcommands_help'] = 'Aide';
$labels['listcommands_subscribe'] = 'S\'abonner';
$labels['listcommands_unsubscribe'] = 'Se désabonner';
$labels['listcommands_post'] = 'Envoyer';
$labels['listcommands_admin'] = 'Contactez l\'administrateur';
$labels['listcommands_archive'] = 'Archives de la liste';

?>