<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Рассылка';
$labels['listcommands_help'] = 'Помощь';
$labels['listcommands_subscribe'] = 'Подписаться';
$labels['listcommands_unsubscribe'] = 'Отписаться';
$labels['listcommands_post'] = 'Ответить в рассылку';
$labels['listcommands_admin'] = 'Связаться с администратором';
$labels['listcommands_archive'] = 'Просмотреть Архив';

?>