<?php

$labels = array();
$labels['listcommands_mailinglist'] = 'Lista';
$labels['listcommands_help'] = 'Pomoc';
$labels['listcommands_subscribe'] = 'Subskrybuj';
$labels['listcommands_unsubscribe'] = 'Odsubskrybuj';
$labels['listcommands_post'] = 'Wyślij';
$labels['listcommands_admin'] = 'Kontakt z administratorem';
$labels['listcommands_archive'] = 'Archiwum listy';

?>
